EncryptionMethod

Enum EncryptionMethod 

pub enum EncryptionMethod {
    Aes128 {
        uri: String,
        iv: Option<u128>,
        key_format: KeyFormat,
        key_format_versions: Vec<u64>,
    },
    SampleAes {
        uri: String,
        iv: Option<u128>,
        key_format_versions: Vec<u64>,
    },
    SampleAesCtr {
        uri: String,
        key_format_versions: Vec<u64>,
    },
}
Information about the encryption method of a given MediaSegment.

Variants



Aes128

Fields

uri: String

A URI that specifies how to obtain the key.

iv: Option<u128>

Specifies an initialization vector to be used with the key.

key_format: KeyFormat

Specifies how the key is represented in the resource identified by the URI.

key_format_versions: Vec<u64>

Which versions of the key_format are this key is in compliance with.



SampleAes

Fields

uri: String

A URI that specifies how to obtain the key.

iv: Option<u128>

Specifies an initialization vector to be used with the key.

key_format_versions: Vec<u64>

Which versions of the key_format are this key is in compliance with.



SampleAesCtr

Fields

uri: String

A URI that specifies how to obtain the key.

key_format_versions: Vec<u64>

Which versions of the key_format are this key is in compliance with.