pub struct VariantStream {
pub stream_info: StreamInf,
pub frame_rate: Option<f64>,
pub audio_group_id: Option<String>,
pub video_group_id: Option<String>,
pub subtitles_group_id: Option<String>,
pub closed_captions_group_id: Option<String>,
pub uri: String,
}Expand description
A set of Renditions that can be combined to play the presentation.
Fields
stream_info: StreamInfMetadata for the stream.
frame_rate: Option<f64>Describes the maximum frame rate for all the video in the
VariantStream.
audio_group_id: Option<String>The group id of the audio RenditionGroup that should be used when
playing the presentation.
video_group_id: Option<String>The group id of the video RenditionGroup that should be used when
playing the presentation.
subtitles_group_id: Option<String>The group id of the subtitle RenditionGroup that should be used when
playing the presentation.
closed_captions_group_id: Option<String>The group id of the closed caption RenditionGroup that should be used when
playing the presentation.
uri: StringThe MediaPlaylist that carries a Rendition of the Variant Stream.